@@ -6,6 +6,7 @@ use async_graphql::{
 };
 use poem::{
     handler,
+    listener::TcpListener,
     middleware::AddData,
     route,
     route::get,
@@ -36,6 +37,7 @@ async fn main() {
 
     println!("Playground: http://localhost:3000");
 
-    let server = Server::bind("127.0.0.1:3000").await.unwrap();
+    let listener = TcpListener::bind("127.0.0.1:3000");
+    let server = Server::new(listener).await.unwrap();
     server.run(app).await.unwrap();
 }
