@@ -1,6 +1,6 @@
 use poem::{
-    async_trait, handler, route, route::get, Endpoint, EndpointExt, IntoResponse, Middleware,
-    Request, Response, Server,
+    async_trait, handler, listener::TcpListener, route, route::get, Endpoint, EndpointExt,
+    IntoResponse, Middleware, Request, Response, Server,
 };
 
 struct Log;
@@ -39,6 +39,7 @@ fn index() -> String {
 #[tokio::main]
 async fn main() {
     let app = route().at("/", get(index)).with(Log);
-    let server = Server::bind("127.0.0.1:3000").await.unwrap();
+    let listener = TcpListener::bind("127.0.0.1:3000");
+    let server = Server::new(listener).await.unwrap();
     server.run(app).await.unwrap();
 }
